aboutsummaryrefslogtreecommitdiff
path: root/cores/arduino/Stream.h
diff options
context:
space:
mode:
Diffstat (limited to 'cores/arduino/Stream.h')
-rw-r--r--cores/arduino/Stream.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/cores/arduino/Stream.h b/cores/arduino/Stream.h
index 1633f15..3c6d025 100644
--- a/cores/arduino/Stream.h
+++ b/cores/arduino/Stream.h
@@ -41,7 +41,8 @@ class Stream : public Print
long _timeout; // number of milliseconds to wait for the next char before aborting timed read
long _startMillis; // used for timeout measurement
int timedRead(); // private method to read stream with timeout
- int getNextDigit(); // returns the next numeric digit in the stream or -1 if timeout
+ int timedPeek(); // private method to peek stream with timeout
+ int peekNextDigit(); // returns the next numeric digit in the stream or -1 if timeout
public:
virtual int available() = 0;